@@ -1,5 +1,6 @@
 from zope.interface import implements
 from interfaces import MegamanicEditableObject, MegamanicEditableTemplateObject
+from Products.CMFCore.permissions import ModifyPortalContent
 
 from AccessControl import ClassSecurityInfo
 from Globals import InitializeClass
@@ -119,6 +120,21 @@ class MegamanicEditable:
 
     security = ClassSecurityInfo()
 
+    security.declarePrivate('at_post_create_script')
+    def at_post_create_script(self):
+        parent = self.getParentNode()
+        if parent.isMegamanicEditableTemplateObject() and \
+                parent.getAllowAnonymousAdd():
+            self.plone_utils.addPortalMessage('Remember to publish this object (make viewable) %s as well' % self.getId())
+#        import pdb
+#        pdb.set_trace()
+        # A class inheriting from MegamanicEdit must always have a MegamanicEdit
+        # class as the first superclass
+        for base in self.__class__.__bases__[1:]:
+            if hasattr(base, 'at_post_create_script'):
+                base.at_post_create_script(self)
+                break
+
     security.declarePublic('isMegamanicEditable')
     def isMegamanicEditable(self, object=None):
         "Yes it is."
@@ -185,7 +201,6 @@ class MegamanicEditableTemplateObject(MegamanicEditable):
     def manage_afterAdd(self, item, container):
         """Adds necessary things.."""
         # Why AT default doesn't kick in beats me
-        self.setTableListingFields(('title', 'description'))
         try:
             try:
                 self.invokeFactory(id='added', type_name='Large Plone Folder', title='Add Objects')
@@ -218,6 +233,7 @@ class MegamanicEditableTemplateObject(MegamanicEditable):
                 if content.id != 'added':
                     content.manage_permission('View', roles=['Anonymous'])
                     content.manage_permission('Access contents information', roles=['Anonymous'])
+            self.plone_utils.addPortalMessage('Remember to publish (make viewable for non-logged-in users) this object (%s) as well' % self.getId())
         else:
             self.added.manage_permission('Add portal content', roles=[], acquire=1)
             self.added.manage_permission('View', roles=[], acquire=1)
